/****************************************************************************
** Meta object code from reading C++ file 'nextcloudsetup.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../konlineaccounts/plugins/nextcloud/nextcloudsetup.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nextcloudsetup.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14NextcloudSetupE_t {};
} // unnamed namespace

template <> constexpr inline auto NextcloudSetup::qt_create_metaobjectdata<qt_meta_tag_ZN14NextcloudSetupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NextcloudSetup",
        "QML.Element",
        "auto",
        "builderChanged",
        "",
        "loginUrlChanged",
        "isWorkingChanged",
        "errorMessageChanged",
        "stateChanged",
        "finalUrlHandler",
        "QUrl",
        "url",
        "checkServer",
        "server",
        "isWorking",
        "errorMessage",
        "state",
        "State",
        "webengineProfile",
        "QQuickWebEngineProfile*",
        "loginUrl",
        "builder",
        "AccountBuilder*",
        "ServerUrl",
        "WebLogin"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'builderChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loginUrlChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isWorkingChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finalUrlHandler'
        QtMocHelpers::SlotData<void(const QUrl &)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'checkServer'
        QtMocHelpers::MethodData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isWorking'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 4),
        // property 'webengineProfile'
        QtMocHelpers::PropertyData<QQuickWebEngineProfile*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'loginUrl'
        QtMocHelpers::PropertyData<QUrl>(20, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'builder'
        QtMocHelpers::PropertyData<AccountBuilder*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(17, 17, QMC::EnumFlags{}).add({
            {   23, State::ServerUrl },
            {   24, State::WebLogin },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NextcloudSetup, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NextcloudSetup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14NextcloudSetupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14NextcloudSetupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14NextcloudSetupE_t>.metaTypes,
    nullptr
} };

void NextcloudSetup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NextcloudSetup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->builderChanged(); break;
        case 1: _t->loginUrlChanged(); break;
        case 2: _t->isWorkingChanged(); break;
        case 3: _t->errorMessageChanged(); break;
        case 4: _t->stateChanged(); break;
        case 5: _t->finalUrlHandler((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->checkServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NextcloudSetup::*)()>(_a, &NextcloudSetup::builderChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NextcloudSetup::*)()>(_a, &NextcloudSetup::loginUrlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NextcloudSetup::*)()>(_a, &NextcloudSetup::isWorkingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NextcloudSetup::*)()>(_a, &NextcloudSetup::errorMessageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NextcloudSetup::*)()>(_a, &NextcloudSetup::stateChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AccountBuilder* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickWebEngineProfile* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isWorking(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        case 2: *reinterpret_cast<enum State*>(_v) = _t->m_state; break;
        case 3: *reinterpret_cast<QQuickWebEngineProfile**>(_v) = _t->m_webengineProfile; break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->m_loginUrl; break;
        case 5: *reinterpret_cast<AccountBuilder**>(_v) = _t->builder(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2:
            if (QtMocHelpers::setProperty(_t->m_state, *reinterpret_cast<enum State*>(_v)))
                Q_EMIT _t->stateChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_loginUrl, *reinterpret_cast<QUrl*>(_v)))
                Q_EMIT _t->loginUrlChanged();
            break;
        case 5: _t->setBuilder(*reinterpret_cast<AccountBuilder**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NextcloudSetup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NextcloudSetup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14NextcloudSetupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NextcloudSetup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void NextcloudSetup::builderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NextcloudSetup::loginUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NextcloudSetup::isWorkingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NextcloudSetup::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NextcloudSetup::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
